# -*- coding:utf-8 -*-
"""
/***************************************************************************
 QualitativeRoute
                Qualitative Spatial Reasoning for routing
 Get a route based on dipole calculi
                              -------------------
        begin                : 2011-06-22
        copyright            : (C) 2011 by German Carrillo (http://geotux.tuxfamily.org)
        email                : gcarrillo@uni-muenster.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
"""
# Import the PyQt and QGIS libraries
from PyQt4.QtCore import *
from PyQt4.QtGui import *
from qgis.core import *
# Initialize Qt resources from file resources.py
import resources_rc

from graph import *

class QualitativeRoute:

    def __init__(self, iface):
        # Save reference to the QGIS interface
        self.iface = iface

    def initGui(self):
        # Create action that will start plugin configuration
        self.action = QAction(QIcon(":/plugins/qualitativeroute/icon.png"), "QSKRR", self.iface.mainWindow())
        # connect the action to the run method
        QObject.connect(self.action, SIGNAL("triggered()"), self.run)

        # Add toolbar button and menu item
        self.iface.addToolBarIcon(self.action)
        self.iface.addPluginToMenu("&QSKRR", self.action)

    def unload(self):
        # Remove the plugin menu item and icon
        self.iface.removePluginMenu("&QSKRR",self.action)
        self.iface.removeToolBarIcon(self.action)

    def run(self):
        legend = self.iface.legendInterface() 
        if len(legend.layers()) == 0:
            QMessageBox.warning( self.iface.mainWindow(), "Warning", 
                    "Please load a layer to the map" )
            return

        # Create the graph object out of the first layer in QGIS TOC
        layer = legend.layers()[0]
        if not layer.type() == 0: # Not a vector layer
            QMessageBox.warning( self.iface.mainWindow(), "Warning", 
                "The first layer has to be a vector layer with lines" )
            return

        pr = layer.dataProvider()
        allAttrs = pr.attributeIndexes()
        layer.select(allAttrs)
        graph = Graph()
        for f in layer:
            line = f.geometry().asPolyline()
            n1 = graph.addNode(line[0].x(), line[0].y()) 
            n2 = graph.addNode(line[len(line)-1].x(), line[len(line)-1].y())
            graph.addEdge(n1, n2)
            graph.addRelFeatNodes(f.id(), n1, n2)

        from dockWidget import DockWidget
        self.wdg = DockWidget(self.iface, self.iface.mainWindow(), self.iface.mapCanvas(), graph)
        self.iface.addDockWidget( Qt.RightDockWidgetArea, self.wdg )    

